accessToken property

LinkedInTokenObject? accessToken
getter/setter pair

Access token if it was provided directly in the authorization response.

In some flows, the access token may be provided directly without needing to exchange the authorization code.

Implementation

LinkedInTokenObject? accessToken;