state property

String? state
getter/setter pair

Unique state string used for security purposes to prevent CSRF attacks.

This should match the state value that was sent in the initial authorization request.

Implementation

String? state;