ExceptionAction class abstract

Base class for actions that represent errors or exceptions.

This abstract class is used for actions that indicate a failure in the LinkedIn authentication or user fetching process.

Inheritance
Implementers
Annotations

Constructors

ExceptionAction(Object exception, [StackTrace? stackTrace])
Creates an ExceptionAction with the error information.
const

Properties

exception Object
The exception that occurred.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace associated with the exception, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override