LinkedAction class abstract

Base class for all actions in the LinkedIn login flow.

Actions are used to communicate state changes and events throughout the authentication and user fetching process.

Implementers
Annotations

Constructors

LinkedAction()
Creates a LinkedAction.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override