LinkedInPreferredLocal class

Represents the user's preferred locale settings.

Contains the country and language preferences for the LinkedIn user.

Constructors

LinkedInPreferredLocal({String? country, String? language})
Creates a LinkedInPreferredLocal with the provided values.
LinkedInPreferredLocal.fromJson(Map<String, dynamic> json)
Creates a LinkedInPreferredLocal from a JSON map.
factory

Properties

country String?
The user's country code (e.g., 'US', 'GB').
final
hashCode int
The hash code for this object.
no setterinherited
language String?
The user's language code (e.g., 'en', 'fr').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited