LinkedInTokenObject class

Represents an OAuth access token and its expiration information.

When you receive an authorization code, you need to exchange it for an access token. This class contains the access token and its expiration time.

Example:

LinkedInTokenObject token = LinkedInTokenObject(
  accessToken: 'your_access_token',
  expiresIn: 3600, // expires in 1 hour
);

Constructors

LinkedInTokenObject({String? accessToken, int? expiresIn})
Creates a LinkedInTokenObject with the provided values.

Properties

accessToken String?
The OAuth access token used to authenticate requests to the LinkedIn API.
getter/setter pair
expiresIn int?
The number of seconds until the access token expires.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited