accessToken property

String? accessToken
getter/setter pair

The OAuth access token used to authenticate requests to the LinkedIn API.

This token should be included in the Authorization header of API requests.

Implementation

String? accessToken;