expiresIn property
The number of seconds until the access token expires.
After this time, the token will no longer be valid and a new token must be obtained.
Implementation
int? expiresIn;
The number of seconds until the access token expires.
After this time, the token will no longer be valid and a new token must be obtained.
int? expiresIn;