UserFailedAction class
Action dispatched when fetching user information fails.
This action is emitted when an error occurs while attempting to fetch the LinkedIn user profile.
- Inheritance
-
- Object
- LinkedAction
- ExceptionAction
- UserFailedAction
- Annotations
Constructors
- UserFailedAction({required Object exception, StackTrace? stackTrace})
-
Creates a UserFailedAction with the error information.
const
Properties
- exception → Object
-
The exception that occurred.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace associated with the exception, if available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited