linkedin_login library
Classes
- AuthorizationCodeResponse
- Response object containing the authorization code and related information from the LinkedIn OAuth flow.
- AuthorizationFailedAction
- Action dispatched when authorization fails.
- AuthorizationSucceededAction
- Action dispatched when authorization is successful.
- EmailAddressScope
- EmailScope
- EnrichedUser
- A LinkedIn user with an associated access token.
- ExceptionAction
- Base class for actions that represent errors or exceptions.
- LinkedAction
- Base class for all actions in the LinkedIn login flow.
- LinkedInAuthCodeWidget
-
This class is responsible to fetch all information for user after we get
token and code from LinkedIn
Please look at documentation for minimum SDK version if you are using
useVirtualDisplay by default library is using
Hybrid Compositionwhich requires minSdkVersion to be 19 - LinkedInButtonStandardWidget
- Class will generate standard flutter button, but with properties you can modify look of the button Also, you don't need to use this widget, you can use standard button widget
- LinkedInPreferredLocal
- Represents the user's preferred locale settings.
- LinkedInTokenObject
- Represents an OAuth access token and its expiration information.
- LinkedInUser
- Base class representing a LinkedIn user's profile information.
- LinkedInUserModel
- A concrete implementation of LinkedInUser created from JSON data.
- LinkedInUserWidget
-
This class is responsible to fetch all information for user after we get
token and code from LinkedIn
Please look at documentation for minimum SDK version if you are using
useVirtualDisplay by default library is using
Hybrid Compositionwhich requires minSdkVersion to be 19 - LiteProfileScope
- OpenIdScope
- ProfileScope
- Scope
- Gives you ability to introduce scope whatever you think its needed.
- UserFailedAction
- Action dispatched when fetching user information fails.
- UserSucceededAction
- Action dispatched when user information is successfully fetched.