AuthorizationCodeResponse constructor
AuthorizationCodeResponse({
- String? code,
- String? state,
- LinkedInTokenObject? accessToken,
Creates an AuthorizationCodeResponse with the provided values.
code is the authorization code that can be exchanged for an access
token.
state is a unique string used for security purposes to prevent CSRF
attacks.
accessToken is the access token if it was provided directly in the
response.
Implementation
AuthorizationCodeResponse({
this.code,
this.state,
this.accessToken,
});