code property
Authorization code that can be exchanged for an access token.
This code is used to obtain an access token from the LinkedIn authorization server.
Implementation
String? code;
Authorization code that can be exchanged for an access token.
This code is used to obtain an access token from the LinkedIn authorization server.
String? code;