state property
Unique state string used for security purposes to prevent CSRF attacks.
This should match the state value that was sent in the initial authorization request.
Implementation
String? state;
Unique state string used for security purposes to prevent CSRF attacks.
This should match the state value that was sent in the initial authorization request.
String? state;