AuthorizationSucceededAction class
Action dispatched when authorization is successful.
This action is emitted when the user successfully authorizes the application and an authorization code is received.
- Inheritance
-
- Object
- LinkedAction
- AuthorizationSucceededAction
- Annotations
Constructors
- AuthorizationSucceededAction(AuthorizationCodeResponse codeResponse)
-
Creates an AuthorizationSucceededAction with the authorization response.
const
Properties
- codeResponse → AuthorizationCodeResponse
-
The authorization code response containing the code and state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited