EnrichedUser class
A LinkedIn user with an associated access token.
This class extends LinkedInUser and includes the access token needed to make authenticated API requests on behalf of the user.
- Inheritance
-
- Object
- LinkedInUser
- EnrichedUser
Constructors
- EnrichedUser({required LinkedInUser user, required LinkedInTokenObject token})
- Creates an EnrichedUser from a LinkedInUser and an access token.
Properties
- email → String?
-
The user's email address.
finalinherited
- familyName → String?
-
The user's family name (last name).
finalinherited
- givenName → String?
-
The user's given name (first name).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmailVerified → bool?
-
Whether the user's email address has been verified by LinkedIn.
finalinherited
- locale → LinkedInPreferredLocal?
-
The user's preferred locale settings.
finalinherited
- name → String?
-
The user's full name.
finalinherited
- picture → String?
-
URL to the user's profile picture.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sub → String?
-
The unique identifier (subject) for the user.
finalinherited
- token → LinkedInTokenObject
-
The access token associated with this user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited