accessToken property
The OAuth access token used to authenticate requests to the LinkedIn API.
This token should be included in the Authorization header of API requests.
Implementation
String? accessToken;
The OAuth access token used to authenticate requests to the LinkedIn API.
This token should be included in the Authorization header of API requests.
String? accessToken;