LinkedInUserModel class
A concrete implementation of LinkedInUser created from JSON data.
This class represents a LinkedIn user profile parsed from the API response.
- Inheritance
-
- Object
- LinkedInUser
- LinkedInUserModel
Constructors
- LinkedInUserModel({required String? name, required String? familyName, required String? givenName, required bool? isEmailVerified, required String? sub, required String? email, required String? picture, required LinkedInPreferredLocal? locale})
-
Creates a LinkedInUserModel with the provided user information.
const
-
LinkedInUserModel.fromJson(Map<
String, dynamic> json) -
Creates a LinkedInUserModel from a JSON map.
factory
Properties
- email → String?
-
The user's email address.
finalinherited
- familyName → String?
-
The user's family name (last name).
finalinherited
- givenName → String?
-
The user's given name (first name).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmailVerified → bool?
-
Whether the user's email address has been verified by LinkedIn.
finalinherited
- locale → LinkedInPreferredLocal?
-
The user's preferred locale settings.
finalinherited
- name → String?
-
The user's full name.
finalinherited
- picture → String?
-
URL to the user's profile picture.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sub → String?
-
The unique identifier (subject) for the user.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited