UserSucceededAction class
Action dispatched when user information is successfully fetched.
This action is emitted when the LinkedIn user profile has been successfully retrieved and includes the user data along with the access token.
- Inheritance
-
- Object
- LinkedAction
- UserSucceededAction
- Annotations
Constructors
- UserSucceededAction(EnrichedUser user)
-
Creates a UserSucceededAction with the fetched user data.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → EnrichedUser
-
The enriched user information including the access token.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited